Facebook
===========

![image](icons/facebook-logo.svg)

Connect to the Facebook Graph API

Signals
-------

- (None)

**Outputs**:

- Corpus

Description
-----------

Create a Corpus of Facebook posts